Overview
========

Python bindings to Windows ServiceControlManager

Checking out the code
=====================

To run this code from the repository for development purposes, run the following:

    easy_install -U infi.projector
    projector devenv build

Python 3
========
Python 3 support is experimental at this stage.
